@@ -3,7 +3,6 @@ CairoSVG - A simple SVG converter based on Cairo.
 
 """
 
-import os
 import sys
 from pathlib import Path
 
@@ -15,9 +14,9 @@ if hasattr(sys, 'frozen'):
     else:
         # Frozen with something else (py2exe, etc.)
         # See https://github.com/Kozea/WeasyPrint/pull/269
-        ROOT = Path(os.path.dirname(sys.executable))
+        ROOT = Path(sys.executable).parent
 else:
-    ROOT = Path(os.path.dirname(__file__))
+    ROOT = Path(__file__).resolve().parent
 
 VERSION = __version__ = (ROOT / 'VERSION').read_text().strip()
 
@@ -96,13 +95,14 @@ def svg2eps(bytestring=None, *, file_obj=None, url=None, dpi=96,
         output_width=output_width, output_height=output_height)
 
 
-svg2svg.__doc__ = surface.Surface.convert.__doc__.replace(
-    'the format for this class', 'SVG')
-svg2png.__doc__ = surface.Surface.convert.__doc__.replace(
-    'the format for this class', 'PNG')
-svg2pdf.__doc__ = surface.Surface.convert.__doc__.replace(
-    'the format for this class', 'PDF')
-svg2ps.__doc__ = surface.Surface.convert.__doc__.replace(
-    'the format for this class', 'PS')
-svg2eps.__doc__ = surface.Surface.convert.__doc__.replace(
-    'the format for this class', 'EPS')
+if __debug__:
+    svg2svg.__doc__ = surface.Surface.convert.__doc__.replace(
+        'the format for this class', 'SVG')
+    svg2png.__doc__ = surface.Surface.convert.__doc__.replace(
+        'the format for this class', 'PNG')
+    svg2pdf.__doc__ = surface.Surface.convert.__doc__.replace(
+        'the format for this class', 'PDF')
+    svg2ps.__doc__ = surface.Surface.convert.__doc__.replace(
+        'the format for this class', 'PS')
+    svg2eps.__doc__ = surface.Surface.convert.__doc__.replace(
+        'the format for this class', 'EPS')
