@@ -4,7 +4,7 @@ Surface helpers.
 """
 
 import re
-from math import atan2, cos, radians, sin, tan
+from math import atan2, cos, hypot, radians, sin, tan
 
 from .surface import cairo
 from .url import parse_url
@@ -13,8 +13,8 @@ UNITS = {
     'mm': 1 / 25.4,
     'cm': 1 / 2.54,
     'in': 1,
-    'pt': 1 / 72.,
-    'pc': 1 / 6.,
+    'pt': 1 / 72,
+    'pc': 1 / 6,
     'px': None,
 }
 
@@ -29,7 +29,7 @@ class PointError(Exception):
 
 def distance(x1, y1, x2, y2):
     """Get the distance between two points."""
-    return ((x2 - x1) ** 2 + (y2 - y1) ** 2) ** 0.5
+    return hypot(x2 - x1, y2 - y1)
 
 
 def paint(value):
@@ -111,8 +111,9 @@ def preserve_ratio(surface, node, width=None, height=None):
         viewbox_width, viewbox_height = node.image_width, node.image_height
     else:
         raise TypeError(
-            ('Root node is {}. Should be one of '
-             'marker, svg, image, or g.').format(node.tag))
+            f'Root node is {node.tag}. Should be one of '
+            'marker, svg, image, or g.'
+        )
 
     translate_x = 0
     translate_y = 0
@@ -263,11 +264,11 @@ def transform(surface, transform_string, gradient=None, transform_origin=None):
         elif transformation_type == 'translate':
             if len(values) == 1:
                 values += (0,)
-            matrix.translate(*values)
+            matrix.translate(*values[:2])
         elif transformation_type == 'scale':
             if len(values) == 1:
                 values = 2 * values
-            matrix.scale(*values)
+            matrix.scale(*values[:2])
 
     if transform_origin:
         matrix.translate(-float(origin_x), -float(origin_y))
@@ -344,8 +345,7 @@ def size(surface, string, reference='xy'):
     If ``reference`` is a float, it is used as reference for percentages. If it
     is ``'x'``, we use the viewport width as reference. If it is ``'y'``, we
     use the viewport height as reference. If it is ``'xy'``, we use
-    ``(viewport_width ** 2 + viewport_height ** 2) ** .5 / 2 ** .5`` as
-    reference.
+    ``hypot(viewport_width, viewport_height) / 2 ** .5`` as reference.
 
     """
     if not string:
@@ -369,15 +369,17 @@ def size(surface, string, reference='xy'):
             reference = surface.context_height or 0
         elif reference == 'xy':
             reference = (
-                (surface.context_width ** 2 +
-                 surface.context_height ** 2) ** .5 /
-                2 ** .5)
+                hypot(surface.context_width, surface.context_height) / 2 ** .5
+            )
         return float(string[:-1]) * reference / 100
     elif string.endswith('em'):
         return surface.font_size * float(string[:-2])
     elif string.endswith('ex'):
         # Assume that 1em == 2ex
         return surface.font_size * float(string[:-2]) / 2
+    elif string.endswith('ch'):
+        # A '0' must be assumed to be 0.5em wide.
+        return surface.font_size * float(string[:-2]) / 2
 
     for unit, coefficient in UNITS.items():
         if string.endswith(unit):
