@@ -1,19 +1,3 @@
-# This file is part of CairoSVG
-# Copyright © 2010-2018 Kozea
-#
-# This library is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, either version 3 of the License, or (at your option) any
-# later version.
-#
-# This library is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
-# details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with CairoSVG.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 SVG Parser.
 
@@ -30,7 +14,7 @@ from defusedxml import ElementTree
 from . import css
 from .features import match_features
 from .helpers import flatten, pop_rotation, rotations
-from .url import fetch, parse_url, read_url
+from .url import fetch, parse_url, read_url, safe_fetch
 
 # 'display' is actually inherited but handled differently because some markers
 # are part of a none-displaying group (see test painting-marker-07-f.svg)
@@ -49,6 +33,7 @@ NOT_INHERITED_ATTRIBUTES = frozenset((
     'stop-opacity',
     'style',
     'transform',
+    'transform-origin',
     'viewBox',
     'width',
     'x',
@@ -183,7 +168,7 @@ class Node(dict):
         self.tag = (
             element.local_name
             if element.namespace_url in ('', 'http://www.w3.org/2000/svg') else
-            '{%s}%s' % (element.namespace_url, element.local_name))
+            f'{{{element.namespace_url}}}{element.local_name}')
         self.text = node.text
         self.url_fetcher = url_fetcher
         self.unsafe = unsafe
@@ -388,6 +373,8 @@ class Tree(Node):
         else:
             raise TypeError(
                 'No input. Use one of bytestring, file_obj or url.')
+        if isinstance(bytestring, str):
+            bytestring = bytestring.encode()
         self_is_parent = (
             (parent and self.url == parent.url) or
             (url and url.startswith('#') and not self.url))
@@ -400,11 +387,16 @@ class Tree(Node):
             if not bytestring:
                 bytestring = self.fetch_url(
                     parse_url(self.url), 'image/svg+xml')
-            if len(bytestring) >= 2 and bytestring[:2] == b'\x1f\x8b':
+            if bytestring.startswith(b'\x1f\x8b'):
                 bytestring = gzip.decompress(bytestring)
             tree = ElementTree.fromstring(
                 bytestring, forbid_entities=not unsafe,
                 forbid_external=not unsafe)
+
+        # Don’t allow fetching external files unless explicitly asked for
+        if 'url_fetcher' not in kwargs and not unsafe:
+            self.url_fetcher = safe_fetch
+
         self.xml_tree = tree
         root = cssselect2.ElementWrapper.from_xml_root(tree)
         style = parent.style if parent else css.parse_stylesheets(self, url)
@@ -416,7 +408,7 @@ class Tree(Node):
                     break
             else:
                 raise TypeError(
-                    'No tag with id="{}" found.'.format(element_id))
+                    f'No tag with id="{element_id}" found.')
         super().__init__(
             root, style, self.url_fetcher, parent, parent_children, self.url,
             unsafe)
