@@ -31,6 +31,7 @@ SHAPE_ANTIALIAS = {
 }
 
 TEXT_ANTIALIAS = {
+    'crispEdges': cairo.ANTIALIAS_NONE,
     'optimizeSpeed': cairo.ANTIALIAS_FAST,
     'optimizeLegibility': cairo.ANTIALIAS_GOOD,
     'geometricPrecision': cairo.ANTIALIAS_BEST,
@@ -112,7 +113,8 @@ class Surface(object):
         :param parent_width: The width of the parent container in pixels.
         :param parent_height: The height of the parent container in pixels.
         :param scale: The ouptut scaling factor.
-        :param unsafe: A boolean allowing XML entities and very large files
+        :param unsafe: A boolean allowing external file access, XML entities
+                       and very large files
                        (WARNING: vulnerable to XXE attacks and various DoS).
 
         Specifiy the output with:
@@ -231,8 +233,8 @@ class Surface(object):
     def device_units_per_user_units(self):
         """Ratio between Cairo device units and user units.
 
-        Device units are points for everything but PNG, and pixels for
-        PNG. User units are pixels.
+        Device units are pixels for PNG and SVG, and points for everything
+        else. User units are pixels.
 
         """
         return self.points_per_pixel
@@ -384,6 +386,7 @@ class Surface(object):
                 self.stroke_and_fill = False
                 self.draw(path)
                 self.stroke_and_fill = True
+                path.tag = 'clipPath'
                 self.context.restore()
                 # TODO: fill rules are not handled by cairo for clips
                 # if node.get('clip-rule') == 'evenodd':
@@ -432,9 +435,9 @@ class Surface(object):
             # Fill
             self.context.save()
             paint_source, paint_color = paint(node.get('fill', 'black'))
+            if node.get('fill-rule') == 'evenodd':
+                self.context.set_fill_rule(cairo.FILL_RULE_EVEN_ODD)
             if not gradient_or_pattern(self, node, paint_source, fill_opacity):
-                if node.get('fill-rule') == 'evenodd':
-                    self.context.set_fill_rule(cairo.FILL_RULE_EVEN_ODD)
                 self.context.set_source_rgba(
                     *self.map_color(paint_color, fill_opacity))
             if TAGS[node.tag] == text:
@@ -518,8 +521,8 @@ class PNGSurface(Surface):
 
     def _create_surface(self, width, height):
         """Create and return ``(cairo_surface, width, height)``."""
-        width = int(width)
-        height = int(height)
+        width = int(round(width))
+        height = int(round(height))
         cairo_surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
         return cairo_surface, width, height
 
@@ -537,6 +540,7 @@ class SVGSurface(Surface):
     with ``output=None`` to get a vector-based single page cairo surface.
 
     """
+    device_units_per_user_units = 1
     surface_class = cairo.SVGSurface
 
 
